@@ -1,6 +1,6 @@
 from google.cloud import bigquery
 from datetime import datetime
-
+import json
 from airflow_commons.logger import LOGGER
 from airflow_commons.sql_resources import (
     GET_COLUMN_NAMES_SQL_FILE,
@@ -10,11 +10,12 @@ from airflow_commons.sql_resources import (
 from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.glossary import COMMA
 
-
 MEGABYTES_BILLED_DENOMINATOR = 2 ** 20
 AVAILABLE_COLUMN_NAMES = ["column_name", "field_path", "table_name"]
 DEFAULT_TIMEOUT = 60
 DEFAULT_LOCATION = "US"
+DEFAULT_RETURN_TYPE = "dataframe"
+SELECT_RETURN_TYPES = ["dict", "json", "dataframe"]
 
 
 def connect(service_account_file: str):
@@ -150,10 +151,17 @@ def query_information_schema(
     return df_columns[requested_column_name].to_list()
 
 
-def select(client: bigquery.Client, sql: str, timeout: int, location: str):
+def select(
+    client: bigquery.Client,
+    sql: str,
+    timeout: int,
+    location: str,
+    return_type: str = DEFAULT_RETURN_TYPE,
+):
     """
     Runs a select query and returns results as dataframe
 
+    :param return_type: dataframe, json or dictionary; default is dataframe
     :param client: Client needed for API request
     :param sql: query sql
     :param timeout: job timeout parameter
@@ -161,13 +169,26 @@ def select(client: bigquery.Client, sql: str, timeout: int, location: str):
     :return: a dataframe of query result
     """
     job_config = bigquery.QueryJobConfig()
-    return query(
+    result = query(
         client=client,
         job_config=job_config,
         sql=sql,
         timeout=timeout,
         location=location,
-    ).to_dataframe()
+    )
+    if return_type == "json":
+        return json.loads(result.to_dataframe().to_json(orient="records"))
+    elif return_type == "dict":
+        return result.to_dataframe().to_dict(orient="records")
+    elif return_type == "dataframe":
+        return result.to_dataframe()
+    else:
+        raise ValueError(
+            "Invalid requested return type:{}. Acceptable return types are ".format(
+                return_type
+            )
+            + COMMA.join(i for i in SELECT_RETURN_TYPES)
+        )
 
 
 def single_value_select(
